package com.flyfish.framework.handler;

import com.flyfish.framework.bean.Result;
import com.flyfish.framework.configuration.jwt.TokenProvider;
import com.flyfish.framework.transform.DataBufferTransformer;
import lombok.RequiredArgsConstructor;
import org.springframework.http.MediaType;
import org.springframework.http.server.reactive.ServerHttpResponse;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.server.WebFilterExchange;
import org.springframework.security.web.server.authentication.logout.ServerLogoutSuccessHandler;
import reactor.core.publisher.Mono;

/**
 * 退出登录的回调
 *
 * @author wangyu
 */
@RequiredArgsConstructor
public class JsonLogoutSuccessHandler implements ServerLogoutSuccessHandler {

    // 数据块工厂
    private final DataBufferTransformer<Result<?>> dataBufferTransformer;

    private final TokenProvider tokenProvider;

    @Override
    public Mono<Void> onLogoutSuccess(WebFilterExchange webFilterExchange, Authentication authentication) {
        ServerHttpResponse response = webFilterExchange.getExchange().getResponse();
        response.getHeaders().setContentType(MediaType.APPLICATION_JSON);
        tokenProvider.removeToken(webFilterExchange.getExchange());
        // 查询
        return response.writeWith(Mono.just(dataBufferTransformer.transform(Result.ok())));
    }
}
